==> jc-tke-client-1.0.136-sources.jar: com/xforceplus/ultraman/app/jctke/controller/GoodsReceiptFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * 收货单feign客户端
 *
 * @author ultraman
 * @date 2022-04-14
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.GoodsReceipt;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface GoodsReceiptFeignApi {

  /**
   * 通过id查询收货单
   * @param  id
   * @return R
   */
  @GetMapping("/goodsReceipt/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增收货单
   * @param goodsReceipt 收货单
   * @return R
   */
  @PostMapping("/goodsReceipt/add")
  public R save(@RequestBody GoodsReceipt goodsReceipt);

  /**
   * 修改收货单
   * @param goodsReceipt 收货单
   * @return R
   */
  @PostMapping("/goodsReceipt/update")
  public R updateById(@RequestBody GoodsReceipt goodsReceipt);

  /**
   * 通过id删除收货单
   * @param  id
   * @return R
   */
  @DeleteMapping("/goodsReceipt/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-tke-client-1.0.170-sources.jar: com/xforceplus/ultraman/app/jctke/controller/GoodsReceiptFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * 收货单（废弃）feign客户端
 *
 * @author ultraman
 * @date 2022-04-19
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.GoodsReceipt;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface GoodsReceiptFeignApi {

  /**
   * 通过id查询收货单（废弃）
   * @param  id
   * @return R
   */
  @GetMapping("/goodsReceipt/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增收货单（废弃）
   * @param goodsReceipt 收货单（废弃）
   * @return R
   */
  @PostMapping("/goodsReceipt/add")
  public R save(@RequestBody GoodsReceipt goodsReceipt);

  /**
   * 修改收货单（废弃）
   * @param goodsReceipt 收货单（废弃）
   * @return R
   */
  @PostMapping("/goodsReceipt/update")
  public R updateById(@RequestBody GoodsReceipt goodsReceipt);

  /**
   * 通过id删除收货单（废弃）
   * @param  id
   * @return R
   */
  @DeleteMapping("/goodsReceipt/del/{id}" )
  public R removeById(@PathVariable Long id);

}
